==> jc-1.4.0.tar.gz: javax/swing/plaf/BorderUIResource__24EtchedBorderUIResource.h <==
// public class javax.swing.plaf.BorderUIResource$EtchedBorderUIResource

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class 76a3a2afae0f4daf javax_swing_border_EtchedBorder
// @dep_class f62b127028e50dae javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource

// header file dependencies
// @dep_header javax_swing_border_EtchedBorder

#include "javax/swing/border/EtchedBorder.h"

#ifndef _JC_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource_H_
#define _JC_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$sub_refs	_jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$sub_nonrefs	_jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$refs	_jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$nonrefs	_jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$object	_jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$object;

typedef struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$fields_struct	_jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$fields_struct;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$vmethods	_jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$vtable	_jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$vtype	_jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$fields_struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$object *);
extern void _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$object *, jint);
extern void _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$method$_init$41d172494a98484a(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$object *, jint, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *);
extern void _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$method$_init$1d46384a8c5f805d(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_border_EtchedBorder$vmethods	javax_swing_border_EtchedBorder;
	_jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$vmethods	javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$refs {
    _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$sub_refs	javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource;
    _jc_javax_swing_border_EtchedBorder$sub_refs	javax_swing_border_EtchedBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_border_EtchedBorder$sub_nonrefs	javax_swing_border_EtchedBorder;
    _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$sub_nonrefs	javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$object {
	_jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$vtype _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/BorderUIResource__24EtchedBorderUIResource.h <==
// public class javax.swing.plaf.BorderUIResource$EtchedBorderUIResource

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class 76a3a2afae0f4daf javax_swing_border_EtchedBorder
// @dep_class f62b127028e50dae javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource

// header file dependencies
// @dep_header javax_swing_border_EtchedBorder

#include "javax/swing/border/EtchedBorder.h"

#ifndef _JC_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource_H_
#define _JC_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$sub_refs	_jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$sub_nonrefs	_jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$refs	_jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$nonrefs	_jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$object	_jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$object;

typedef struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$fields_struct	_jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$fields_struct;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$vmethods	_jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$vtable	_jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$vtype	_jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$fields_struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$object *, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$method$_init$41d172494a98484a(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$object *, jint, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$method$_init$1d46384a8c5f805d(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_border_EtchedBorder$vmethods	javax_swing_border_EtchedBorder;
	_jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$vmethods	javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$refs {
    _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$sub_refs	javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource;
    _jc_javax_swing_border_EtchedBorder$sub_refs	javax_swing_border_EtchedBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_border_EtchedBorder$sub_nonrefs	javax_swing_border_EtchedBorder;
    _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$sub_nonrefs	javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$object {
	_jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$vtype _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_BorderUIResource__24EtchedBorderUIResource_H_ */
